summaryrefslogtreecommitdiff
path: root/sys/dev
diff options
context:
space:
mode:
authormrg <mrg@NetBSD.org>2011-11-24 03:35:56 +0000
committermrg <mrg@NetBSD.org>2011-11-24 03:35:56 +0000
commite29a9c27350bcafb3eebeffb7f63d6914c74e8d7 (patch)
treeb7a960486d864a199a089456274b886efbe92e8d /sys/dev
parent45eacf9f28829b7eebd72ef89c7494b65c0f3146 (diff)
put back IPL_AUDIO and splaudio(), at the request of rmind. they are
aliases and now we can easily revert audio to IPL_VM if necessary, without having to revert the whole branch.
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/acpi/mpu_acpi.c6
-rw-r--r--sys/dev/ic/interwave.c8
-rw-r--r--sys/dev/isa/aria.c8
-rw-r--r--sys/dev/isa/ess.c10
-rw-r--r--sys/dev/isa/gus.c8
-rw-r--r--sys/dev/isa/mpu_isa.c8
-rw-r--r--sys/dev/isa/pas.c8
-rw-r--r--sys/dev/isa/sb_isa.c8
-rw-r--r--sys/dev/isa/wss.c8
-rw-r--r--sys/dev/isa/ym.c8
-rw-r--r--sys/dev/isapnp/mpu_isapnp.c8
-rw-r--r--sys/dev/pci/auacer.c8
-rw-r--r--sys/dev/pci/auich.c8
-rw-r--r--sys/dev/pci/auixp.c10
-rw-r--r--sys/dev/pci/autri.c8
-rw-r--r--sys/dev/pci/auvia.c8
-rw-r--r--sys/dev/pci/azalia.c8
-rw-r--r--sys/dev/pci/cmpci.c8
-rw-r--r--sys/dev/pci/cs4280.c8
-rw-r--r--sys/dev/pci/cs4281.c8
-rw-r--r--sys/dev/pci/eap.c8
-rw-r--r--sys/dev/pci/emuxki.c12
-rw-r--r--sys/dev/pci/esa.c8
-rw-r--r--sys/dev/pci/esm.c8
-rw-r--r--sys/dev/pci/eso.c8
-rw-r--r--sys/dev/pci/fms.c8
-rw-r--r--sys/dev/pci/gcscaudio.c8
-rw-r--r--sys/dev/pci/hdaudio/hdaudio.c8
-rw-r--r--sys/dev/pci/hdaudio/hdaudio_pci.c6
-rw-r--r--sys/dev/pci/neo.c8
-rw-r--r--sys/dev/pci/sv.c8
-rw-r--r--sys/dev/pci/yds.c10
32 files changed, 131 insertions, 131 deletions
diff --git a/sys/dev/acpi/mpu_acpi.c b/sys/dev/acpi/mpu_acpi.c
index 83e89f2bbb6..57b836b90b0 100644
--- a/sys/dev/acpi/mpu_acpi.c
+++ b/sys/dev/acpi/mpu_acpi.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mpu_acpi.c,v 1.11 2011/11/23 23:07:31 jmcneill Exp $ */
+/* $NetBSD: mpu_acpi.c,v 1.12 2011/11/24 03:35:57 mrg Exp $ */
/*
* Copyright (c) 2002 Jared D. McNeill <jmcneill@invisible.ca>
@@ -30,7 +30,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mpu_acpi.c,v 1.11 2011/11/23 23:07:31 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mpu_acpi.c,v 1.12 2011/11/24 03:35:57 mrg Exp $");
#include <sys/param.h>
#include <sys/device.h>
@@ -122,7 +122,7 @@ mpu_acpi_attach(device_t parent, device_t self, void *aux)
sc->arg = isa_intr_establish(aa->aa_ic, irq->ar_irq,
(irq->ar_type == ACPI_EDGE_SENSITIVE) ? IST_EDGE : IST_LEVEL,
- IPL_SCHED, mpu_intr, sc);
+ IPL_AUDIO, mpu_intr, sc);
out:
acpi_resource_cleanup(&res);
diff --git a/sys/dev/ic/interwave.c b/sys/dev/ic/interwave.c
index bab58f12154..b0b844e1b17 100644
--- a/sys/dev/ic/interwave.c
+++ b/sys/dev/ic/interwave.c
@@ -1,4 +1,4 @@
-/* $NetBSD: interwave.c,v 1.35 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: interwave.c,v 1.36 2011/11/24 03:35:57 mrg Exp $ */
/*
* Copyright (c) 1997, 1999, 2008 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: interwave.c,v 1.35 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: interwave.c,v 1.36 2011/11/24 03:35:57 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -192,7 +192,7 @@ iwattach(struct iw_softc *sc)
sc->sc_dma_flags = 0;
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/*
* We can only use a few selected irqs, see if we got one from pnp
@@ -201,7 +201,7 @@ iwattach(struct iw_softc *sc)
if (sc->sc_irq > 0) {
sc->sc_ih = isa_intr_establish(sc->sc_p2xr_ic,
- sc->sc_irq, IST_EDGE, IPL_SCHED, iwintr, sc);
+ sc->sc_irq, IST_EDGE, IPL_AUDIO, iwintr, sc);
got_irq = 1;
}
if (!got_irq) {
diff --git a/sys/dev/isa/aria.c b/sys/dev/isa/aria.c
index 8c4f3ba73b3..87674fd3a15 100644
--- a/sys/dev/isa/aria.c
+++ b/sys/dev/isa/aria.c
@@ -1,4 +1,4 @@
-/* $NetBSD: aria.c,v 1.34 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: aria.c,v 1.35 2011/11/24 03:35:57 mrg Exp $ */
/*-
* Copyright (c) 1995, 1996, 1998 The NetBSD Foundation, Inc.
@@ -50,7 +50,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: aria.c,v 1.34 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: aria.c,v 1.35 2011/11/24 03:35:57 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -414,10 +414,10 @@ ariaattach(device_t parent, device_t self, void *aux)
sc->sc_ic = ia->ia_ic;
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->sc_ih = isa_intr_establish(ia->ia_ic, ia->ia_irq[0].ir_irq,
- IST_EDGE, IPL_SCHED, aria_intr, sc);
+ IST_EDGE, IPL_AUDIO, aria_intr, sc);
DPRINTF(("isa_intr_establish() returns (%p)\n", sc->sc_ih));
diff --git a/sys/dev/isa/ess.c b/sys/dev/isa/ess.c
index 02f61defdd4..a409dd76067 100644
--- a/sys/dev/isa/ess.c
+++ b/sys/dev/isa/ess.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ess.c,v 1.79 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: ess.c,v 1.80 2011/11/24 03:35:57 mrg Exp $ */
/*
* Copyright 1997
@@ -66,7 +66,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ess.c,v 1.79 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ess.c,v 1.80 2011/11/24 03:35:57 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -926,12 +926,12 @@ essattach(struct ess_softc *sc, int enablejoy)
callout_init(&sc->sc_poll1_ch, CALLOUT_MPSAFE);
callout_init(&sc->sc_poll2_ch, CALLOUT_MPSAFE);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->sc_audio1.polled = sc->sc_audio1.irq == -1;
if (!sc->sc_audio1.polled) {
sc->sc_audio1.ih = isa_intr_establish(sc->sc_ic,
- sc->sc_audio1.irq, sc->sc_audio1.ist, IPL_SCHED,
+ sc->sc_audio1.irq, sc->sc_audio1.ist, IPL_AUDIO,
ess_audio1_intr, sc);
aprint_normal_dev(sc->sc_dev,
"audio1 interrupting at irq %d\n", sc->sc_audio1.irq);
@@ -956,7 +956,7 @@ essattach(struct ess_softc *sc, int enablejoy)
sc->sc_audio2.polled = sc->sc_audio2.irq == -1;
if (!sc->sc_audio2.polled) {
sc->sc_audio2.ih = isa_intr_establish(sc->sc_ic,
- sc->sc_audio2.irq, sc->sc_audio2.ist, IPL_SCHED,
+ sc->sc_audio2.irq, sc->sc_audio2.ist, IPL_AUDIO,
ess_audio2_intr, sc);
aprint_normal_dev(sc->sc_dev,
"audio2 interrupting at irq %d\n",
diff --git a/sys/dev/isa/gus.c b/sys/dev/isa/gus.c
index d3a83e56407..e516b2c5c48 100644
--- a/sys/dev/isa/gus.c
+++ b/sys/dev/isa/gus.c
@@ -1,4 +1,4 @@
-/* $NetBSD: gus.c,v 1.107 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: gus.c,v 1.108 2011/11/24 03:35:57 mrg Exp $ */
/*-
* Copyright (c) 1996, 1999, 2008 The NetBSD Foundation, Inc.
@@ -88,7 +88,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gus.c,v 1.107 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gus.c,v 1.108 2011/11/24 03:35:57 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -820,7 +820,7 @@ gusattach(device_t parent, device_t self, void *aux)
sc = (void *) self;
ia = aux;
callout_init(&sc->sc_dmaout_ch, CALLOUT_MPSAFE);
- ad1848_init_locks(&sc->sc_codec.sc_ad1848, IPL_SCHED);
+ ad1848_init_locks(&sc->sc_codec.sc_ad1848, IPL_AUDIO);
sc->sc_iot = iot = ia->ia_iot;
sc->sc_ic = ia->ia_ic;
@@ -1036,7 +1036,7 @@ gusattach(device_t parent, device_t self, void *aux)
*/
sc->sc_ih = isa_intr_establish(ia->ia_ic, ia->ia_irq[0].ir_irq,
- IST_EDGE, IPL_SCHED, gusintr, sc /* sc->sc_gusdsp */);
+ IST_EDGE, IPL_AUDIO, gusintr, sc /* sc->sc_gusdsp */);
/*
* Set some default values
diff --git a/sys/dev/isa/mpu_isa.c b/sys/dev/isa/mpu_isa.c
index 22ac4dd0b2f..686514a6fba 100644
--- a/sys/dev/isa/mpu_isa.c
+++ b/sys/dev/isa/mpu_isa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: mpu_isa.c,v 1.21 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: mpu_isa.c,v 1.22 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 1999, 2008 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mpu_isa.c,v 1.21 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mpu_isa.c,v 1.22 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -115,11 +115,11 @@ mpu_isa_attach(device_t parent, device_t self, void *aux)
}
sc->sc_ih = isa_intr_establish(ia->ia_ic, ia->ia_irq[0].ir_irq,
- IST_EDGE, IPL_SCHED, mpu_intr, &sc->sc_mpu);
+ IST_EDGE, IPL_AUDIO, mpu_intr, &sc->sc_mpu);
sc->sc_mpu.model = "Roland MPU-401 MIDI UART";
sc->sc_dev = self;
sc->sc_mpu.lock = &sc->sc_lock;
- mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_AUDIO);
mpu_attach(&sc->sc_mpu);
}
diff --git a/sys/dev/isa/pas.c b/sys/dev/isa/pas.c
index 3d6b4658773..376f34cbe53 100644
--- a/sys/dev/isa/pas.c
+++ b/sys/dev/isa/pas.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pas.c,v 1.69 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: pas.c,v 1.70 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 1991-1993 Regents of the University of California.
@@ -57,7 +57,7 @@
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pas.c,v 1.69 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pas.c,v 1.70 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -473,12 +473,12 @@ pasattach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_sbdsp.sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_sbdsp.sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_sbdsp.sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->sc_sbdsp.sc_ic = ia->ia_ic;
sc->sc_sbdsp.sc_iobase = iobase;
sc->sc_sbdsp.sc_ih = isa_intr_establish(ia->ia_ic, ia->ia_irq[0].ir_irq,
- IST_EDGE, IPL_SCHED, sbdsp_intr, &sc->sc_sbdsp);
+ IST_EDGE, IPL_AUDIO, sbdsp_intr, &sc->sc_sbdsp);
aprint_normal(" ProAudio Spectrum %s [rev %d] ", pasnames[sc->model],
sc->rev);
diff --git a/sys/dev/isa/sb_isa.c b/sys/dev/isa/sb_isa.c
index fb41807c95f..f745315f0b9 100644
--- a/sys/dev/isa/sb_isa.c
+++ b/sys/dev/isa/sb_isa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: sb_isa.c,v 1.37 2011/11/23 23:07:32 jmcneill Exp $ */
+/* $NetBSD: sb_isa.c,v 1.38 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 1991-1993 Regents of the University of California.
@@ -35,7 +35,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sb_isa.c,v 1.37 2011/11/23 23:07:32 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sb_isa.c,v 1.38 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -172,10 +172,10 @@ sb_isa_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->sc_ih = isa_intr_establish(ia->ia_ic, ia->ia_irq[0].ir_irq,
- IST_EDGE, IPL_SCHED, sbdsp_intr, sc);
+ IST_EDGE, IPL_AUDIO, sbdsp_intr, sc);
sbattach(sc);
}
diff --git a/sys/dev/isa/wss.c b/sys/dev/isa/wss.c
index 64c8cff6f6e..381e0383535 100644
--- a/sys/dev/isa/wss.c
+++ b/sys/dev/isa/wss.c
@@ -1,4 +1,4 @@
-/* $NetBSD: wss.c,v 1.70 2011/11/23 23:07:33 jmcneill Exp $ */
+/* $NetBSD: wss.c,v 1.71 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 1994 John Brezak
@@ -36,7 +36,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: wss.c,v 1.70 2011/11/23 23:07:33 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: wss.c,v 1.71 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -129,12 +129,12 @@ wssattach(struct wss_softc *sc)
ac = &sc->sc_ad1848.sc_ad1848;
- ad1848_init_locks(ac, IPL_SCHED);
+ ad1848_init_locks(ac, IPL_AUDIO);
madattach(sc);
sc->sc_ad1848.sc_ih = isa_intr_establish(sc->wss_ic, sc->wss_irq,
- IST_EDGE, IPL_SCHED, wss_intr, &sc->sc_ad1848);
+ IST_EDGE, IPL_AUDIO, wss_intr, &sc->sc_ad1848);
ad1848_isa_attach(&sc->sc_ad1848);
diff --git a/sys/dev/isa/ym.c b/sys/dev/isa/ym.c
index 5d387374ba4..e5e8ea69d75 100644
--- a/sys/dev/isa/ym.c
+++ b/sys/dev/isa/ym.c
@@ -1,4 +1,4 @@
-/* $NetBSD: ym.c,v 1.42 2011/11/23 23:07:33 jmcneill Exp $ */
+/* $NetBSD: ym.c,v 1.43 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 1999-2002, 2008 The NetBSD Foundation, Inc.
@@ -60,7 +60,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ym.c,v 1.42 2011/11/23 23:07:33 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ym.c,v 1.43 2011/11/24 03:35:58 mrg Exp $");
#include "mpu_ym.h"
#include "opt_ym.h"
@@ -214,7 +214,7 @@ ym_attach(struct ym_softc *sc)
ac = &sc->sc_ad1848.sc_ad1848;
callout_init(&sc->sc_powerdown_ch, CALLOUT_MPSAFE);
cv_init(&sc->sc_cv, "ym");
- ad1848_init_locks(ac, IPL_SCHED);
+ ad1848_init_locks(ac, IPL_AUDIO);
/* Mute the output to reduce noise during initialization. */
ym_mute(sc, SA3_VOL_L, 1);
@@ -224,7 +224,7 @@ ym_attach(struct ym_softc *sc)
ac->chip_name = YM_IS_SA3(sc) ? "OPL3-SA3" : "OPL3-SA2";
sc->sc_ad1848.sc_ih = isa_intr_establish(sc->sc_ic, sc->ym_irq,
- IST_EDGE, IPL_SCHED, ym_intr, sc);
+ IST_EDGE, IPL_AUDIO, ym_intr, sc);
#ifndef AUDIO_NO_POWER_CTL
sc->sc_ad1848.powerctl = ym_codec_power_ctl;
diff --git a/sys/dev/isapnp/mpu_isapnp.c b/sys/dev/isapnp/mpu_isapnp.c
index 123036f88c0..e024fdd9e9c 100644
--- a/sys/dev/isapnp/mpu_isapnp.c
+++ b/sys/dev/isapnp/mpu_isapnp.c
@@ -1,7 +1,7 @@
-/* $NetBSD: mpu_isapnp.c,v 1.18 2011/11/23 23:07:33 jmcneill Exp $ */
+/* $NetBSD: mpu_isapnp.c,v 1.19 2011/11/24 03:35:58 mrg Exp $ */
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mpu_isapnp.c,v 1.18 2011/11/23 23:07:33 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mpu_isapnp.c,v 1.19 2011/11/24 03:35:58 mrg Exp $");
#include "midi.h"
@@ -65,7 +65,7 @@ mpu_isapnp_attach(device_t parent, device_t self, void *aux)
return;
}
- mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->sc_mpu.iot = ipa->ipa_iot;
sc->sc_mpu.ioh = ipa->ipa_io[0].h;
@@ -85,5 +85,5 @@ mpu_isapnp_attach(device_t parent, device_t self, void *aux)
midi_attach_mi(&mpu_midi_hw_if, &sc->sc_mpu, self);
sc->sc_ih = isa_intr_establish(ipa->ipa_ic, ipa->ipa_irq[0].num,
- ipa->ipa_irq[0].type, IPL_SCHED, mpu_intr, &sc->sc_mpu);
+ ipa->ipa_irq[0].type, IPL_AUDIO, mpu_intr, &sc->sc_mpu);
}
diff --git a/sys/dev/pci/auacer.c b/sys/dev/pci/auacer.c
index 125daacd3cd..43b7ab70bac 100644
--- a/sys/dev/pci/auacer.c
+++ b/sys/dev/pci/auacer.c
@@ -1,4 +1,4 @@
-/* $NetBSD: auacer.c,v 1.29 2011/11/23 23:07:33 jmcneill Exp $ */
+/* $NetBSD: auacer.c,v 1.30 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 2004, 2008 The NetBSD Foundation, Inc.
@@ -44,7 +44,7 @@
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: auacer.c,v 1.29 2011/11/23 23:07:33 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: auacer.c,v 1.30 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -276,7 +276,7 @@ auacer_attach(device_t parent, device_t self, void *aux)
sc->sc_dmamap_flags = BUS_DMA_COHERENT; /* XXX remove */
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* enable bus mastering */
v = pci_conf_read(pa->pa_pc, pa->pa_tag, PCI_COMMAND_STATUS_REG);
@@ -291,7 +291,7 @@ auacer_attach(device_t parent, device_t self, void *aux)
return;
}
intrstr = pci_intr_string(pa->pa_pc, ih);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO,
auacer_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "can't establish interrupt");
diff --git a/sys/dev/pci/auich.c b/sys/dev/pci/auich.c
index ba002822d51..0802e962710 100644
--- a/sys/dev/pci/auich.c
+++ b/sys/dev/pci/auich.c
@@ -1,4 +1,4 @@
-/* $NetBSD: auich.c,v 1.139 2011/11/23 23:07:34 jmcneill Exp $ */
+/* $NetBSD: auich.c,v 1.140 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 2000, 2004, 2005, 2008 The NetBSD Foundation, Inc.
@@ -111,7 +111,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: auich.c,v 1.139 2011/11/23 23:07:34 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: auich.c,v 1.140 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -526,7 +526,7 @@ map_done:
v | PCI_COMMAND_MASTER_ENABLE | PCI_COMMAND_BACKTOBACK_ENABLE);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* Map and establish the interrupt. */
if (pci_intr_map(pa, &sc->intrh)) {
@@ -534,7 +534,7 @@ map_done:
return;
}
intrstr = pci_intr_string(pa->pa_pc, sc->intrh);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, sc->intrh, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, sc->intrh, IPL_AUDIO,
auich_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(self, "can't establish interrupt");
diff --git a/sys/dev/pci/autri.c b/sys/dev/pci/autri.c
index 962131d06a2..e9d7d470702 100644
--- a/sys/dev/pci/autri.c
+++ b/sys/dev/pci/autri.c
@@ -1,4 +1,4 @@
-/* $NetBSD: autri.c,v 1.47 2011/11/23 23:07:34 jmcneill Exp $ */
+/* $NetBSD: autri.c,v 1.48 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 2001 SOMEYA Yoshihiko and KUROSAWA Takahiro.
@@ -35,7 +35,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: autri.c,v 1.47 2011/11/23 23:07:34 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: autri.c,v 1.48 2011/11/24 03:35:58 mrg Exp $");
#include "midi.h"
@@ -544,7 +544,7 @@ autri_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* map and establish the interrupt */
if (pci_intr_map(pa, &ih)) {
@@ -552,7 +552,7 @@ autri_attach(device_t parent, device_t self, void *aux)
return;
}
intrstr = pci_intr_string(pc, ih);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, autri_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, autri_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/auvia.c b/sys/dev/pci/auvia.c
index 3f709c72f23..ccdf3a57ab0 100644
--- a/sys/dev/pci/auvia.c
+++ b/sys/dev/pci/auvia.c
@@ -1,4 +1,4 @@
-/* $NetBSD: auvia.c,v 1.74 2011/11/23 23:07:34 jmcneill Exp $ */
+/* $NetBSD: auvia.c,v 1.75 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 2000, 2008 The NetBSD Foundation, Inc.
@@ -40,7 +40,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: auvia.c,v 1.74 2011/11/23 23:07:34 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: auvia.c,v 1.75 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -426,9 +426,9 @@ auvia_attach(device_t parent, device_t self, void *aux)
intrstr = pci_intr_string(pc, ih);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, auvia_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, auvia_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(sc->sc_dev, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/azalia.c b/sys/dev/pci/azalia.c
index c8e664b8dbb..0624f437296 100644
--- a/sys/dev/pci/azalia.c
+++ b/sys/dev/pci/azalia.c
@@ -1,4 +1,4 @@
-/* $NetBSD: azalia.c,v 1.78 2011/11/23 23:07:34 jmcneill Exp $ */
+/* $NetBSD: azalia.c,v 1.79 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 2005, 2008 The NetBSD Foundation, Inc.
@@ -41,7 +41,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: azalia.c,v 1.78 2011/11/23 23:07:34 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: azalia.c,v 1.79 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/device.h>
@@ -331,12 +331,12 @@ azalia_pci_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
sc->pc = pa->pa_pc;
sc->tag = pa->pa_tag;
intrrupt_str = pci_intr_string(pa->pa_pc, ih);
- sc->ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED, azalia_intr, sc);
+ sc->ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO, azalia_intr, sc);
if (sc->ih == NULL) {
aprint_error_dev(self, "can't establish interrupt");
if (intrrupt_str != NULL)
diff --git a/sys/dev/pci/cmpci.c b/sys/dev/pci/cmpci.c
index bde3b992b13..7e12cc277de 100644
--- a/sys/dev/pci/cmpci.c
+++ b/sys/dev/pci/cmpci.c
@@ -1,4 +1,4 @@
-/* $NetBSD: cmpci.c,v 1.43 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: cmpci.c,v 1.44 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 2000, 2001, 2008 The NetBSD Foundation, Inc.
@@ -43,7 +43,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cmpci.c,v 1.43 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cmpci.c,v 1.44 2011/11/24 03:35:58 mrg Exp $");
#if defined(AUDIO_DEBUG) || defined(DEBUG)
#define DPRINTF(x) if (cmpcidebug) printf x
@@ -414,7 +414,7 @@ cmpci_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* interrupt */
if (pci_intr_map(pa, &ih)) {
@@ -422,7 +422,7 @@ cmpci_attach(device_t parent, device_t self, void *aux)
return;
}
strintr = pci_intr_string(pa->pa_pc, ih);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED, cmpci_intr,
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO, cmpci_intr,
sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "failed to establish interrupt");
diff --git a/sys/dev/pci/cs4280.c b/sys/dev/pci/cs4280.c
index cbd49ad4ad5..f853cffb52b 100644
--- a/sys/dev/pci/cs4280.c
+++ b/sys/dev/pci/cs4280.c
@@ -1,4 +1,4 @@
-/* $NetBSD: cs4280.c,v 1.62 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: cs4280.c,v 1.63 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 1999, 2000 Tatoku Ogaito. All rights reserved.
@@ -52,7 +52,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cs4280.c,v 1.62 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cs4280.c,v 1.63 2011/11/24 03:35:58 mrg Exp $");
#include "midi.h"
@@ -326,9 +326,9 @@ cs4280_attach(device_t parent, device_t self, void *aux)
intrstr = pci_intr_string(pc, sc->intrh);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
- sc->sc_ih = pci_intr_establish(sc->sc_pc, sc->intrh, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(sc->sc_pc, sc->intrh, IPL_AUDIO,
cs4280_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
diff --git a/sys/dev/pci/cs4281.c b/sys/dev/pci/cs4281.c
index 9e247c39389..1bac62c43d5 100644
--- a/sys/dev/pci/cs4281.c
+++ b/sys/dev/pci/cs4281.c
@@ -1,4 +1,4 @@
-/* $NetBSD: cs4281.c,v 1.45 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: cs4281.c,v 1.46 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 2000 Tatoku Ogaito. All rights reserved.
@@ -43,7 +43,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cs4281.c,v 1.45 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cs4281.c,v 1.46 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -250,9 +250,9 @@ cs4281_attach(device_t parent, device_t self, void *aux)
intrstr = pci_intr_string(pc, sc->intrh);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
- sc->sc_ih = pci_intr_establish(sc->sc_pc, sc->intrh, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(sc->sc_pc, sc->intrh, IPL_AUDIO,
cs4281_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
diff --git a/sys/dev/pci/eap.c b/sys/dev/pci/eap.c
index e7016595d7c..b518e660160 100644
--- a/sys/dev/pci/eap.c
+++ b/sys/dev/pci/eap.c
@@ -1,4 +1,4 @@
-/* $NetBSD: eap.c,v 1.93 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: eap.c,v 1.94 2011/11/24 03:35:58 mrg Exp $ */
/* $OpenBSD: eap.c,v 1.6 1999/10/05 19:24:42 csapuntz Exp $ */
/*
@@ -51,7 +51,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: eap.c,v 1.93 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: eap.c,v 1.94 2011/11/24 03:35:58 mrg Exp $");
#include "midi.h"
#include "joy_eap.h"
@@ -542,7 +542,7 @@ eap_attach(device_t parent, device_t self, void *aux)
aprint_naive(": Audio controller\n");
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* Stash this away for detach */
sc->sc_pc = pc;
@@ -600,7 +600,7 @@ eap_attach(device_t parent, device_t self, void *aux)
return;
}
intrstr = pci_intr_string(pc, ih);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, eap_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, eap_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(sc->sc_dev, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/emuxki.c b/sys/dev/pci/emuxki.c
index 78da57f43ca..282b6d84db4 100644
--- a/sys/dev/pci/emuxki.c
+++ b/sys/dev/pci/emuxki.c
@@ -1,4 +1,4 @@
-/* $NetBSD: emuxki.c,v 1.60 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: emuxki.c,v 1.61 2011/11/24 03:35:58 mrg Exp $ */
/*-
* Copyright (c) 2001, 2007 The NetBSD Foundation, Inc.
@@ -49,7 +49,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: emuxki.c,v 1.60 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: emuxki.c,v 1.61 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/device.h>
@@ -414,9 +414,9 @@ emuxki_attach(device_t parent, device_t self, void *aux)
aprint_naive(": Audio controller\n");
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
- mutex_init(&sc->sc_index_lock, MUTEX_DEFAULT, IPL_SCHED);
- mutex_init(&sc->sc_ac97_index_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
+ mutex_init(&sc->sc_index_lock, MUTEX_DEFAULT, IPL_AUDIO);
+ mutex_init(&sc->sc_ac97_index_lock, MUTEX_DEFAULT, IPL_AUDIO);
if (pci_mapreg_map(pa, EMU_PCI_CBIO, PCI_MAPREG_TYPE_IO, 0,
&(sc->sc_iot), &(sc->sc_ioh), &(sc->sc_iob),
@@ -440,7 +440,7 @@ emuxki_attach(device_t parent, device_t self, void *aux)
}
intrstr = pci_intr_string(pa->pa_pc, ih);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED, emuxki_intr,
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO, emuxki_intr,
sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(self, "couldn't establish interrupt");
diff --git a/sys/dev/pci/esa.c b/sys/dev/pci/esa.c
index 2c2f291ed63..b08a02e477f 100644
--- a/sys/dev/pci/esa.c
+++ b/sys/dev/pci/esa.c
@@ -1,4 +1,4 @@
-/* $NetBSD: esa.c,v 1.55 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: esa.c,v 1.56 2011/11/24 03:35:59 mrg Exp $ */
/*
* Copyright (c) 2001-2008 Jared D. McNeill <jmcneill@invisible.ca>
@@ -39,7 +39,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: esa.c,v 1.55 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: esa.c,v 1.56 2011/11/24 03:35:59 mrg Exp $");
#include <sys/types.h>
#include <sys/errno.h>
@@ -1049,7 +1049,7 @@ esa_attach(device_t parent, device_t self, void *aux)
sc->sc_dmat = pa->pa_dmat;
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* Map and establish an interrupt */
if (pci_intr_map(pa, &ih)) {
@@ -1059,7 +1059,7 @@ esa_attach(device_t parent, device_t self, void *aux)
return;
}
intrstr = pci_intr_string(pc, ih);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, esa_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, esa_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(sc->sc_dev, "can't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/esm.c b/sys/dev/pci/esm.c
index 67c656ceb61..221590f1574 100644
--- a/sys/dev/pci/esm.c
+++ b/sys/dev/pci/esm.c
@@ -1,4 +1,4 @@
-/* $NetBSD: esm.c,v 1.54 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: esm.c,v 1.55 2011/11/24 03:35:59 mrg Exp $ */
/*-
* Copyright (c) 2002, 2003 Matt Fredette
@@ -66,7 +66,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: esm.c,v 1.54 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: esm.c,v 1.55 2011/11/24 03:35:59 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -1613,7 +1613,7 @@ esm_attach(device_t parent, device_t self, void *aux)
aprint_normal(": %s (rev. 0x%02x)\n", devinfo, revision);
mutex_init(&ess->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&ess->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&ess->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
/* Enable the device. */
csr = pci_conf_read(pc, tag, PCI_COMMAND_STATUS_REG);
@@ -1650,7 +1650,7 @@ esm_attach(device_t parent, device_t self, void *aux)
return;
}
intrstr = pci_intr_string(pc, ih);
- ess->ih = pci_intr_establish(pc, ih, IPL_SCHED, esm_intr, self);
+ ess->ih = pci_intr_establish(pc, ih, IPL_AUDIO, esm_intr, self);
if (ess->ih == NULL) {
aprint_error_dev(ess->sc_dev, "can't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/eso.c b/sys/dev/pci/eso.c
index 1fa8cb2b013..f9aacef6329 100644
--- a/sys/dev/pci/eso.c
+++ b/sys/dev/pci/eso.c
@@ -1,4 +1,4 @@
-/* $NetBSD: eso.c,v 1.58 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: eso.c,v 1.59 2011/11/24 03:35:59 mrg Exp $ */
/*-
* Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -62,7 +62,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: eso.c,v 1.58 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: eso.c,v 1.59 2011/11/24 03:35:59 mrg Exp $");
#include "mpu.h"
@@ -382,10 +382,10 @@ eso_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
intrstring = pci_intr_string(pa->pa_pc, ih);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED, eso_intr, sc);
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO, eso_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
if (intrstring != NULL)
diff --git a/sys/dev/pci/fms.c b/sys/dev/pci/fms.c
index 114e9c2ce0c..d3079d8cfd6 100644
--- a/sys/dev/pci/fms.c
+++ b/sys/dev/pci/fms.c
@@ -1,4 +1,4 @@
-/* $NetBSD: fms.c,v 1.39 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: fms.c,v 1.40 2011/11/24 03:35:59 mrg Exp $ */
/*-
* Copyright (c) 1999, 2008 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: fms.c,v 1.39 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fms.c,v 1.40 2011/11/24 03:35:59 mrg Exp $");
#include "mpu.h"
@@ -260,9 +260,9 @@ fms_attach(device_t parent, device_t self, void *aux)
intrstr = pci_intr_string(pc, ih);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, fms_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, fms_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/gcscaudio.c b/sys/dev/pci/gcscaudio.c
index aad1a558bee..f8746f95991 100644
--- a/sys/dev/pci/gcscaudio.c
+++ b/sys/dev/pci/gcscaudio.c
@@ -1,4 +1,4 @@
-/* $NetBSD: gcscaudio.c,v 1.8 2011/11/23 23:07:35 jmcneill Exp $ */
+/* $NetBSD: gcscaudio.c,v 1.9 2011/11/24 03:35:59 mrg Exp $ */
/*-
* Copyright (c) 2008 SHIMIZU Ryo <ryo@nerv.org>
@@ -27,7 +27,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gcscaudio.c,v 1.8 2011/11/23 23:07:35 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gcscaudio.c,v 1.9 2011/11/24 03:35:59 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -275,7 +275,7 @@ gcscaudio_attach(device_t parent, device_t self, void *aux)
LIST_INIT(&sc->sc_dmalist);
sc->sc_mch_split_buf = NULL;
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
aprint_normal(": AMD Geode CS5536 Audio\n");
@@ -291,7 +291,7 @@ gcscaudio_attach(device_t parent, device_t self, void *aux)
}
intrstr = pci_intr_string(sc->sc_pc, ih);
- sc->sc_ih = pci_intr_establish(sc->sc_pc, ih, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(sc->sc_pc, ih, IPL_AUDIO,
gcscaudio_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
diff --git a/sys/dev/pci/hdaudio/hdaudio.c b/sys/dev/pci/hdaudio/hdaudio.c
index 8bb0c75f934..59f5b37635a 100644
--- a/sys/dev/pci/hdaudio/hdaudio.c
+++ b/sys/dev/pci/hdaudio/hdaudio.c
@@ -1,4 +1,4 @@
-/* $NetBSD: hdaudio.c,v 1.17 2011/11/23 23:07:36 jmcneill Exp $ */
+/* $NetBSD: hdaudio.c,v 1.18 2011/11/24 03:35:59 mrg Exp $ */
/*
* Copyright (c) 2009 Precedence Technologies Ltd <support@precedence.co.uk>
@@ -30,7 +30,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: hdaudio.c,v 1.17 2011/11/23 23:07:36 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: hdaudio.c,v 1.18 2011/11/24 03:35:59 mrg Exp $");
#include <sys/types.h>
#include <sys/param.h>
@@ -778,8 +778,8 @@ hdaudio_attach(device_t dev, struct hdaudio_softc *sc)
KASSERT(sc->sc_memvalid == true);
sc->sc_dev = dev;
- mutex_init(&sc->sc_corb_mtx, MUTEX_DEFAULT, IPL_SCHED);
- mutex_init(&sc->sc_stream_mtx, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_corb_mtx, MUTEX_DEFAULT, IPL_AUDIO);
+ mutex_init(&sc->sc_stream_mtx, MUTEX_DEFAULT, IPL_AUDIO);
hdaudio_init(sc);
diff --git a/sys/dev/pci/hdaudio/hdaudio_pci.c b/sys/dev/pci/hdaudio/hdaudio_pci.c
index 5d22bfdc566..2017c2a69d5 100644
--- a/sys/dev/pci/hdaudio/hdaudio_pci.c
+++ b/sys/dev/pci/hdaudio/hdaudio_pci.c
@@ -1,4 +1,4 @@
-/* $NetBSD: hdaudio_pci.c,v 1.9 2011/11/23 23:07:36 jmcneill Exp $ */
+/* $NetBSD: hdaudio_pci.c,v 1.10 2011/11/24 03:35:59 mrg Exp $ */
/*
* Copyright (c) 2009 Precedence Technologies Ltd <support@precedence.co.uk>
@@ -34,7 +34,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: hdaudio_pci.c,v 1.9 2011/11/23 23:07:36 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: hdaudio_pci.c,v 1.10 2011/11/24 03:35:59 mrg Exp $");
#include <sys/types.h>
#include <sys/param.h>
@@ -141,7 +141,7 @@ hdaudio_pci_attach(device_t parent, device_t self, void *opaque)
return;
}
intrstr = pci_intr_string(pa->pa_pc, ih);
- sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_SCHED,
+ sc->sc_ih = pci_intr_establish(pa->pa_pc, ih, IPL_AUDIO,
hdaudio_pci_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(self, "couldn't establish interrupt");
diff --git a/sys/dev/pci/neo.c b/sys/dev/pci/neo.c
index 688f3a0b0ce..550cb899268 100644
--- a/sys/dev/pci/neo.c
+++ b/sys/dev/pci/neo.c
@@ -1,4 +1,4 @@
-/* $NetBSD: neo.c,v 1.46 2011/11/23 23:07:36 jmcneill Exp $ */
+/* $NetBSD: neo.c,v 1.47 2011/11/24 03:35:59 mrg Exp $ */
/*
* Copyright (c) 1999 Cameron Grant <gandalf@vilnya.demon.co.uk>
@@ -32,7 +32,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: neo.c,v 1.46 2011/11/23 23:07:36 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: neo.c,v 1.47 2011/11/24 03:35:59 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -606,10 +606,10 @@ neo_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
intrstr = pci_intr_string(pc, ih);
- sc->ih = pci_intr_establish(pc, ih, IPL_SCHED, neo_intr, sc);
+ sc->ih = pci_intr_establish(pc, ih, IPL_AUDIO, neo_intr, sc);
if (sc->ih == NULL) {
aprint_error_dev(&sc->dev, "couldn't establish interrupt");
diff --git a/sys/dev/pci/sv.c b/sys/dev/pci/sv.c
index 657a39708b3..62912c26be4 100644
--- a/sys/dev/pci/sv.c
+++ b/sys/dev/pci/sv.c
@@ -1,4 +1,4 @@
-/* $NetBSD: sv.c,v 1.45 2011/11/23 23:07:36 jmcneill Exp $ */
+/* $NetBSD: sv.c,v 1.46 2011/11/24 03:35:58 mrg Exp $ */
/* $OpenBSD: sv.c,v 1.2 1998/07/13 01:50:15 csapuntz Exp $ */
/*
@@ -67,7 +67,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sv.c,v 1.45 2011/11/23 23:07:36 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sv.c,v 1.46 2011/11/24 03:35:58 mrg Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -427,10 +427,10 @@ sv_attach(device_t parent, device_t self, void *aux)
}
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
intrstr = pci_intr_string(pc, ih);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, sv_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, sv_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/yds.c b/sys/dev/pci/yds.c
index fa6075c3b86..f34c4861069 100644
--- a/sys/dev/pci/yds.c
+++ b/sys/dev/pci/yds.c
@@ -1,4 +1,4 @@
-/* $NetBSD: yds.c,v 1.51 2011/11/23 23:07:36 jmcneill Exp $ */
+/* $NetBSD: yds.c,v 1.52 2011/11/24 03:35:59 mrg Exp $ */
/*
* Copyright (c) 2000, 2001 Kazuki Sakamoto and Minoura Makoto.
@@ -39,7 +39,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: yds.c,v 1.51 2011/11/23 23:07:36 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: yds.c,v 1.52 2011/11/24 03:35:59 mrg Exp $");
#include "mpu.h"
@@ -766,11 +766,11 @@ yds_attach(device_t parent, device_t self, void *aux)
return;
}
- mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_SCHED);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_AUDIO); /* XXX IPL_NONE? */
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
intrstr = pci_intr_string(pc, ih);
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, yds_intr, sc);
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, yds_intr, sc);
if (sc->sc_ih == NULL) {
aprint_error_dev(self, "couldn't establish interrupt");
if (intrstr != NULL)
diff --git a/sys/dev/pci/auixp.c b/sys/dev/pci/auixp.c
index d7f875ea55a..8150b55d2ac 100644
--- a/sys/dev/pci/auixp.c
+++ b/sys/dev/pci/auixp.c
@@ -1,4 +1,4 @@
-/* $NetBSD: auixp.c,v 1.35 2011/11/23 23:07:34 jmcneill Exp $ */
+/* $NetBSD: auixp.c,v 1.36 2011/11/24 03:35:58 mrg Exp $ */
/*
* Copyright (c) 2004, 2005 Reinoud Zandijk <reinoud@netbsd.org>
@@ -50,7 +50,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: auixp.c,v 1.35 2011/11/23 23:07:34 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: auixp.c,v 1.36 2011/11/24 03:35:58 mrg Exp $");
#include <sys/types.h>
#include <sys/errno.h>
@@ -1169,10 +1169,10 @@ auixp_attach(device_t parent, device_t self, void *aux)
intrstr = pci_intr_string(pc, ih);
mutex_init(&sc->sc_lock, MUTEX_DEFAULT, IPL_NONE);
- mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_SCHED);
+ mutex_init(&sc->sc_intr_lock, MUTEX_DEFAULT, IPL_AUDIO);
- /* establish interrupt routine hookup at IPL_SCHED level */
- sc->sc_ih = pci_intr_establish(pc, ih, IPL_SCHED, auixp_intr, self);
+ /* establish interrupt routine hookup at IPL_AUDIO level */
+ sc->sc_ih = pci_intr_establish(pc, ih, IPL_AUDIO, auixp_intr, self);
if (sc->sc_ih == NULL) {
aprint_error_dev(&sc->sc_dev, "can't establish interrupt");
if (intrstr != NULL)